Change in osmo-bts[master]: cosmetic: rename *_meas_rep_fn10* to *_meas_re_fn10*_by_*s

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

dexter gerrit-no-reply at lists.osmocom.org
Tue Aug 28 15:43:22 UTC 2018


dexter has uploaded this change for review. ( https://gerrit.osmocom.org/10655


Change subject: cosmetic: rename *_meas_rep_fn10* to *_meas_re_fn10*_by_*s
......................................................................

cosmetic: rename *_meas_rep_fn10* to *_meas_re_fn10*_by_*s

The lookup table that control the measurement interval endings do not
make clear what their indexes refer to. Lets give them more distinct
names.

rename sdcch8_meas_rep_fn102 to sdcch8_meas_re_fn102_by_ss
rename sdcch4_meas_rep_fn102 to sdcch4_meas_re_fn102_by_ss
rename tchf_meas_rep_fn104 to tchf_meas_re_fn104_by_ts
rename tchh0_meas_rep_fn104 to tchh0_meas_re_fn104_by_ts
rename tchh1_meas_rep_fn104 to tchh1_meas_re_fn104_by_ts

Change-Id: I3dc891e1860109f803c1bfa46445e8fef35586d9
Related: OS#2975
---
M src/common/measurement.c
1 file changed, 16 insertions(+), 16 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/osmo-bts refs/changes/55/10655/1

diff --git a/src/common/measurement.c b/src/common/measurement.c
index 2a7d7de..3ce7882 100644
--- a/src/common/measurement.c
+++ b/src/common/measurement.c
@@ -119,7 +119,7 @@
  * Note: The array index of the following three lookup tables refes to a
  *       timeslot number. */
 
-static const uint8_t tchf_meas_rep_fn104[] = {
+static const uint8_t tchf_meas_re_fn104_by_ts[] = {
 	[0] =	90,
 	[1] =	103,
 	[2] =	12,
@@ -129,7 +129,7 @@
 	[6] =	64,
 	[7] =	77,
 };
-static const uint8_t tchh0_meas_rep_fn104[] = {
+static const uint8_t tchh0_meas_re_fn104_by_ts[] = {
 	[0] =	90,
 	[1] =	90,
 	[2] =	12,
@@ -139,7 +139,7 @@
 	[6] =	64,
 	[7] =	64,
 };
-static const uint8_t tchh1_meas_rep_fn104[] = {
+static const uint8_t tchh1_meas_re_fn104_by_ts[] = {
 	[0] =	103,
 	[1] =	103,
 	[2] =	25,
@@ -164,7 +164,7 @@
  *       subslot number. */
 
 /* FN of the first burst whose block completes before reaching fn%102=11 */
-static const uint8_t sdcch8_meas_rep_fn102[] = {
+static const uint8_t sdcch8_meas_re_fn102_by_ss[] = {
 	[0] = 66,	/* 15(SDCCH), 47(SACCH), 66(SDCCH) */
 	[1] = 70,	/* 19(SDCCH), 51(SACCH), 70(SDCCH) */
 	[2] = 74,	/* 23(SDCCH), 55(SACCH), 74(SDCCH) */
@@ -176,7 +176,7 @@
 };
 
 /* FN of the first burst whose block completes before reaching fn%102=37 */
-static const uint8_t sdcch4_meas_rep_fn102[] = {
+static const uint8_t sdcch4_meas_re_fn102_by_ss[] = {
 	[0] = 88,	/* 37(SDCCH), 57(SACCH), 88(SDCCH) */
 	[1] = 92,	/* 41(SDCCH), 61(SACCH), 92(SDCCH) */
 	[2] = 6,	/*  6(SACCH), 47(SDCCH), 98(SDCCH) */
@@ -195,7 +195,7 @@
  * Table 1 of 9) what value we need to feed into the lookup tables in order to
  * detect the measurement period ending. In this example the "real" ending
  * was on FN%104=12. This is the value we have to look for in
  * tchf_meas_rep_fn104 to know that a measurement period has just ended. */
 
 /* See also 3GPP TS 05.02 Clause 7 Table 1 of 9:
  * Mapping of logical channels onto physical channels (see subclauses 6.3, 6.4, 6.5) */
@@ -266,28 +266,28 @@
 	switch (pchan) {
 	case GSM_PCHAN_TCH_F:
 		fn_mod = translate_tch_meas_rep_fn104(fn % 104);
-		if (tchf_meas_rep_fn104[lchan->ts->nr] == fn_mod)
+		if (tchf_meas_re_fn104_by_ts[lchan->ts->nr] == fn_mod)
 			rc = 1;
 		break;
 	case GSM_PCHAN_TCH_H:
 		fn_mod = translate_tch_meas_rep_fn104(fn % 104);
 		if (lchan->nr == 0)
-			tbl = tchh0_meas_rep_fn104;
+			tbl = tchh0_meas_re_fn104_by_ts;
 		else
-			tbl = tchh1_meas_rep_fn104;
+			tbl = tchh1_meas_re_fn104_by_ts;
 		if (tbl[lchan->ts->nr] == fn_mod)
 			rc = 1;
 		break;
 	case GSM_PCHAN_SDCCH8_SACCH8C:
 	case GSM_PCHAN_SDCCH8_SACCH8C_CBCH:
 		fn_mod = fn % 102;
-		if (sdcch8_meas_rep_fn102[lchan->nr] == fn_mod)
+		if (sdcch8_meas_re_fn102_by_ss[lchan->nr] == fn_mod)
 			rc = 1;
 		break;
 	case GSM_PCHAN_CCCH_SDCCH4:
 	case GSM_PCHAN_CCCH_SDCCH4_CBCH:
 		fn_mod = fn % 102;
-		if (sdcch4_meas_rep_fn102[lchan->nr] == fn_mod)
+		if (sdcch4_meas_re_fn102_by_ss[lchan->nr] == fn_mod)
 			rc = 1;
 		break;
 	default:
@@ -330,27 +330,27 @@
 	switch (pchan) {
 	case GSM_PCHAN_TCH_F:
 		modulus = 104;
-		interval_end = tchf_meas_rep_fn104[lchan->ts->nr];
+		interval_end = tchf_meas_re_fn104_by_ts[lchan->ts->nr];
 		interval_end = translate_tch_meas_rep_fn104_inv(interval_end);
 		break;
 	case GSM_PCHAN_TCH_H:
 		modulus = 104;
 		if (lchan->nr == 0)
-			tbl = tchh0_meas_rep_fn104;
+			tbl = tchh0_meas_re_fn104_by_ts;
 		else
-			tbl = tchh1_meas_rep_fn104;
+			tbl = tchh1_meas_re_fn104_by_ts;
 		interval_end = tbl[lchan->ts->nr];
 		interval_end = translate_tch_meas_rep_fn104_inv(interval_end);
 		break;
 	case GSM_PCHAN_SDCCH8_SACCH8C:
 	case GSM_PCHAN_SDCCH8_SACCH8C_CBCH:
 		modulus = 102;
-		interval_end = sdcch8_meas_rep_fn102[lchan->nr];
+		interval_end = sdcch8_meas_re_fn102_by_ss[lchan->nr];
 		break;
 	case GSM_PCHAN_CCCH_SDCCH4:
 	case GSM_PCHAN_CCCH_SDCCH4_CBCH:
 		modulus = 102;
-		interval_end = sdcch4_meas_rep_fn102[lchan->nr];
+		interval_end = sdcch4_meas_re_fn102_by_ss[lchan->nr];
 		break;
 	default:
 		return false;
@@ -195,7 +195,7 @@
  * detect the measurement period ending. In this example the "real" ending
  * was on FN%104=12. This is the value we have to look for in
- * tchf_meas_rep_fn104 to know that a measurement period has just ended. */
+ * tchf_meas_re_fn104_by_ts to know that a measurement period has just ended. */
 
 /* See also 3GPP TS 05.02 Clause 7 Table 1 of 9:

-- 
To view, visit https://gerrit.osmocom.org/10655
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-MessageType: newchange
Gerrit-Change-Id: I3dc891e1860109f803c1bfa46445e8fef35586d9
Gerrit-Change-Number: 10655
Gerrit-PatchSet: 1
Gerrit-Owner: dexter <pmaier at sysmocom.de>
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20180828/eba75233/attachment.htm>


More information about the gerrit-log mailing list